@@ -9,4 +9,8 @@ pub struct Arguments {
     pub directory: Option<String>,
     #[clap(short, help = "Set a job limit")]
     pub job_limit: Option<usize>,
+    #[clap(long, help = "Set a log prefix")]
+    pub log_prefix: Option<String>,
+    #[clap(long, help = "Show debug output")]
+    pub debug: bool,
 }
